@@ -1,4 +1,4 @@
-__version__ = '0.0.6.2'
+__version__ = '0.0.7'
 
 
 import win32api
@@ -11,6 +11,7 @@ import cv2
 import numpy as np
 import re
 import os
+import onnxruntime
 
 from ctypes import windll
 from threading import Thread
